<?php

namespace Drupal\commerce_payu_webcheckout\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Defines the PayuHash entity.
 *
 * @ContentEntityType(
 *   id = "payu_hash",
 *   label = @Translation("PayU Hash"),
 *   base_table = "payu_hash",
 *   entity_keys = {
 *     "id" = "id",
 *     "uid" = "uid",
 *     "order_id" = "order_id",
 *     "hash" = "hash",
 *     "created" = "created",
 *   },
 *   fieldable = FALSE,
 * )
 */
class Hash extends ContentEntityBase implements ContentEntityInterface {

  /**
   * Id accessor.
   *
   * @return int
   *   The Id.
   */
  public function getId() {
    return $this->get('id')->value;
  }

  /**
   * Hash accessor.
   *
   * @return string
   *   The hash.
   */
  public function getHash() {
    return $this->get('hash')->value;
  }

  /**
   * Order ID accessor.
   *
   * @return int
   *   The order ID.
   */
  public function getOrder() {
    return $this->get('order_id')->entity;
  }

  /**
   * UID accessor.
   *
   * @return int
   *   The order owner.
   */
  public function getUser() {
    return $this->get('uid')->entity;
  }

  /**
   * Created accessor.
   *
   * @return int
   *   The created timestamp.
   */
  public function created() {
    return $this->get('created')->value;
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields['id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the Hash entity.'))
      ->setReadOnly(TRUE);

    $fields['uid'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('UID'))
      ->setDescription(t('The Order owner'))
      ->setSetting('target_type', 'user')
      ->setSetting('handler', 'default')
      ->setReadOnly(TRUE);

    $fields['order_id'] = BaseFieldDefinition::create('entity_reference')
      ->setLabel(t('Order ID'))
      ->setDescription(t('The order ID attached to this hash.'))
      ->setSetting('target_type', 'commerce_order')
      ->setSetting('handler', 'default')
      ->setReadOnly(TRUE);

    $fields['hash'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Hash'))
      ->setDescription(t('The hash value.'))
      ->setRequired(TRUE)
      ->setSetting('max_length', 255)
      ->setReadOnly(TRUE);

    $fields['created'] = BaseFieldDefinition::create('created')
      ->setLabel(t('Created'))
      ->setRequired(TRUE)
      ->setDescription(t('The time when the order was placed.'))
      ->setReadOnly(TRUE);

    return $fields;
  }

  /**
   * Creates a Hash using PayU's recommended MD5 method.
   *
   * @return string
   *   The MD5 String.
   */
  public static function createHash() {
    return md5(implode('~', func_get_args()));
  }

}
