<?php

namespace Drupal\commerce_payu_webcheckout\Plugin\Commerce\CheckoutPane;

use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides the Payu WebCheckout Summary pane.
 *
 * @CommerceCheckoutPane(
 *   id = "payu_webcheckout_summary_pane",
 *   label = @Translation("Payu WebCheckout Summary"),
 *   admin_label = @Translation("Payu Webcheckout Summary pane"),
 *   default_step = "complete",
 *   wrapper_element = "container",
 * )
 */
class PayuWebSummaryPane extends CheckoutPaneBase implements ContainerFactoryPluginInterface {

  const PAYU_SUCCESSFUL = '4';

  private $requestStack;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow, RequestStack $request_stack) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $checkout_flow);
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $checkout_flow,
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $request = $this->requestStack->getCurrentRequest();
    if ($request->getMethod() != 'GET') {
      return $pane_form;
    }
    $parameters = $request->query->all();
    if (!isset($parameters['reference_pol'])) {
      return $pane_form;
    }
    $pane_form['order-summary'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Purchase summary'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );
    $whitelisted = array(
      'lapPaymentMethod' => $this->t('Payment method'),
      'buyerEmail' => $this->t('Buyer email'),
      'transactionId' => $this->t('Transaction Id'),
      'lapPaymentMethodType' => $this->t('Payment method type'),
      'lapResponseCode' => $this->t('Response code'),
    );
    $pane_form['order-summary']['table'] = array(
      '#type' => 'table',
      '#header' => array(t('Label'), t('Value')),
    );
    $pane_form['order-summary']['table']['status']['label'] = array(
      '#markup' => '<strong>Status</strong>',
    );
    $pane_form['order-summary']['table']['status']['value'] = array(
      '#markup' => $parameters['transactionState'] == self::PAYU_SUCCESSFUL ? $this->t('Approved') : $this->t('Declined'),
    );
    $whitelisted_keys = array_keys($whitelisted);
    foreach ($parameters as $key => $value) {
      if ((($searchKey = array_search($key, $whitelisted_keys)) !== FALSE) && $value) {
        $pane_form['order-summary']['table'][$key]['label'] = array(
          '#markup' => '<strong>' . $whitelisted[$whitelisted_keys[$searchKey]] . '</strong>',
        );
        $pane_form['order-summary']['table'][$key]['value'] = array(
          '#plain_text' => str_replace('_', ' ', $value),
        );
      }
    }
    $pane_form['summary'] = $this->checkoutFlow->buildOrderSummary($pane_form, $form_state);
    return $pane_form;
  }

}
