<?php

namespace Drupal\commerce_payu_webcheckout\Plugin\Commerce\PaymentGateway;

use Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\PaymentGatewayBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Discovery\YamlDiscovery;

/**
 * Provides the PayU payment gateway.
 *
 * @CommercePaymentGateway(
 *   id = "payu_webcheckout_payment_gateway",
 *   label = "PayU Webcheckout",
 *   display_label = "PayU Webcheckout",
 *   forms = {
 *     "add-payment-method" = "Drupal\commerce_payu_webcheckout\PluginForm\PayuAddForm",
 *   },
 *   payment_method_types = {"payu_webcheckout_payment_type"},
 * )
 */
class PayuWebcheckoutGateway extends PaymentGatewayBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return array(
      'image' => 'no_image',
      'api_key' => '',
      'merchant_id' => '',
      'account_id' => '',
      'order_description' => '',
    ) + parent::defaultConfiguration();
  }

  /**
   * Accessor method for image configuration property.
   *
   * @return string
   *   The machine name of the image selected.
   */
  public function getImageConfiguration() {
    return $this->configuration['image'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $path = drupal_get_path('module', 'commerce_payu_webcheckout');
    $discovery = new YamlDiscovery('images', array('commerce_payu_webcheckout' => $path));
    $definitions = $discovery->findAll();
    $definitions = reset($definitions);

    // Payment method image.
    $form['image'] = array(
      '#type' => 'select',
      '#title' => $this->t('Payment selection image.'),
      '#description' => $this->t('Select the image you would like to have displayed at the payment method pane. The codes you see listed are taken from the official PayU Corporative logo guidelines available <a href="@link">here</a>.', array('@link' => 'http://www.payulatam.com/logos/index.php')),
      '#options' => array(),
      '#default_value' => $this->configuration['image'],
      '#empty_option' => t('No image'),
      '#empty_value' => 'no_image',
    );

    foreach ($definitions['payu_webcheckout_images'] as $key => $definition) {
      $form['image']['#options'][$key] = ucfirst(str_replace('_', ' ', $key));
    }

    $form['payu-settings'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Account settings'),
      '#collapsible' => FALSE,
      '#collapsed' => FALSE,
    );

    $form['payu-settings']['api_key'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Api key'),
      '#description' => $this->t('Your API Key provided by PayU.'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['api_key'],
    );

    $form['payu-settings']['merchant_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Merchant ID'),
      '#description' => $this->t('Your Merchant ID provided by PayU.'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['merchant_id'],
    );

    $form['payu-settings']['account_id'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Account ID'),
      '#description' => $this->t('Your Account ID provided by PayU.'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['account_id'],
    );

    $form['payu-settings']['order_description'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Order description'),
      '#description' => $this->t("The order description customers will see in PayU's payment page."),
      '#required' => TRUE,
      '#default_value' => $this->configuration['order_description'],
    );
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['image'] = $values['image'];
      $this->configuration['api_key'] = $values['payu-settings']['api_key'];
      $this->configuration['merchant_id'] = $values['payu-settings']['merchant_id'];
      $this->configuration['account_id'] = $values['payu-settings']['account_id'];
      $this->configuration['order_description'] = $values['payu-settings']['order_description'];
    }
    parent::submitConfigurationForm($form, $form_state);
  }

}
