<?php

namespace Drupal\commerce_payu_webcheckout\Plugin\Commerce\PaymentType;

use Drupal\commerce\BundleFieldDefinition;
use Drupal\commerce_payment\Plugin\Commerce\PaymentType\PaymentTypeBase;

/**
 * Provides the PayU WebCheckout Payment type.
 *
 * @CommercePaymentType(
 *   id = "payu_webcheckout_payment",
 *   label = @Translation("PayU WebCheckout"),
 *   workflow = "payu_webcheckout_payment"
 * )
 */
class PayuWebcheckoutPayment extends PaymentTypeBase {

  /**
   * Eases the field definition process.
   *
   * @param string $type
   *   The type of field being created.
   * @param string $label
   *   The field label.
   * @param string $description
   *   The field description.
   *
   * @return Drupal\commerce\BundleFieldDefinition
   *   The new field definition.
   */
  private function fieldDefinitionHelper($type, $label, $description) {
    return BundleFieldDefinition::create($type)
      ->setLabel($label)
      ->setDescription($description)
      ->setRequired(FALSE)
      ->setDisplayOptions('view', [
        'label' => 'above',
        'type' => $type,
      ])
      ->setDisplayConfigurable('view', TRUE);
  }

  /**
   * {@inheritdoc}
   */
  public function buildFieldDefinitions() {
    $fields = array();
    $fields['cc_number'] = $this->fieldDefinitionHelper('string', t('Credit card number'), t('The masked credit card number used for the transaction.'));
    $fields['cc_holder'] = $this->fieldDefinitionHelper('string', t('Credit card holder'), t('The credit card holder used for the transaction.'));
    $fields['transaction_date'] = $this->fieldDefinitionHelper('string', t('Transaction date'), t('The date the transaction was performed.'));
    $fields['response_message_pol'] = $this->fieldDefinitionHelper('string', t('Automatic response message'), t('The actual PayU Webcheckout response.'));
    $fields['error_message_bank'] = $this->fieldDefinitionHelper('string', t('Bank response message'), t('The message the bank returned while attempting the transaction. (If any).'));
    $fields['payment_method_name'] = $this->fieldDefinitionHelper('string', t('Payment method'), t('The selected payment method for the transaction.'));
    $fields['pse_bank'] = $this->fieldDefinitionHelper('string', t('PSE Bank'), t('The PSE Bank used for the transaction. (If any).'));
    $fields['currency'] = $this->fieldDefinitionHelper('string', t('Currency'), t('The currency used to perform the transaction.'));
    $fields['exchange_rate'] = $this->fieldDefinitionHelper('decimal', t('Exchange rate'), t('The actual exchange rate at the moment of the transaction.'));
    $fields['ip'] = $this->fieldDefinitionHelper('string', t('Ip'), t("The user's Ip address"));
    return $fields;
  }

}
